@@ -63,6 +63,14 @@ class AwsSeePy:
         self.executeFunction       = None
         self.myPidFile             = None
 
+        self.checkDBs()
+
+    def checkDBs(self):
+        # Correct the missing 'id' field for MFAs
+        for m in self.mfaRepository.all():
+            if 'id' not in m:
+               m['id'] = str(uuid.uuid4())
+               self.mfaRepository.databaseConnection().update(m)
 
     def loadConfigProfiles(self):
         fileConfig  = expanduser("~") + "/.aws/config"
